# CpuInfo

CPU info 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**architecture** | **str** | The CPU architecture | [optional] 
**vendor** | **str** | The CPU vendor | [optional] 
**model** | **str** | The CPU model | [optional] 
**speed** | **int** | The CPU speed, in Mhz. | [optional] 
**cache** | **int** | The CPU cache size in KBs. | [optional] 
**cpus** | **int** | The number of CPUs | [optional] 
**cores** | **int** | The number of CPU cores | [optional] 
**threads** | **int** | The number of CPU threads | [optional] 
**endian** | **str** | The CPU endianess | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


